@@ -17,7 +17,7 @@ if not logger.handlers:
     fh = logging.FileHandler('hackingtools.log')
     fh.setLevel(logging.DEBUG)
     # create formatter and add it to the handlers
-    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+    formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
     fh.setFormatter(formatter)
     # add the handlers to the logger
     logger.addHandler(fh)
