@@ -55,9 +55,10 @@ class StartModule():
 			new_pdf = 'edited-{f}'.format(f=os.path.split(pdf_file)[1])
 			new_file = os.path.join( os.path.split(pdf_file)[0], new_pdf)
 			PdfWriter(new_file, trailer=trailer).write()
+			Logger.printMessage(new_file)
 			return new_file
-		except Exception as e:
-			Logger.printMessage(str(e), is_error=True)
+		except:
+			Logger.printMessage(pdf_file, is_error=True)
 			return pdf_file
 
 	# def get_audio_video_exif(self, filename):
